@@ -1,4 +1,4 @@
-/* $Id: gucharmap-window.c,v 1.65 2006/01/27 22:33:43 behdad Exp $ */
+/* $Id: gucharmap-window.c,v 1.69 2006/02/13 21:46:46 behdad Exp $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -23,7 +23,7 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#if HAVE_GNOME
+#ifdef HAVE_GNOME
 # include <gnome.h>
 #endif
 #include "gucharmap-window.h"
@@ -297,7 +297,7 @@ snap_cols_pow2 (GtkAction 	 *action,
   				 gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)));
 }
 
-#if HAVE_GNOME
+#ifdef HAVE_GNOME
 static void
 help_contents (GtkAction *action,
 	       gpointer  data)
@@ -312,13 +312,15 @@ help_contents (GtkAction *action,
       g_error_free (error);
     }
 }
-#endif /* #if HAVE_GNOME */
+#endif
 
 static void
 help_about (GtkAction       *action, 
             GucharmapWindow *guw)
 {
   GucharmapWindowPrivate *priv = GUCHARMAP_WINDOW_GET_PRIVATE (guw);
+  const gchar *translator_credits;
+  const gchar *license_trans;
 
   const gchar *authors[] = 
     { 
@@ -333,7 +335,30 @@ help_about (GtkAction       *action,
       "Sun Microsystems",
       NULL
     };	  
-  const gchar *translator_credits;
+
+  const gchar *license[] = {
+    N_("Gucharmap is free software; you can redistribute it and/or modify "
+       "it under the terms of the GNU General Public License as published by "
+       "the Free Software Foundation; either version 2 of the License, or "
+       "(at your option) any later version."),
+    N_("Permission is hereby granted, free of charge, to any person obtaining "
+       "a copy of the Unicode data files to deal in them without restriction, "
+       "including without limitation the rights to use, copy, modify, merge, "
+       "publish, distribute, and/or sell copies."),
+    N_("Gucharmap and the Unicode data files are distributed in the hope that "
+       "they will be useful, but WITHOUT ANY WARRANTY; without even the implied "
+       "warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See "
+       "the GNU General Public License and Unicode Copyright for more details."),
+    N_("You should have received a copy of the GNU General Public License "
+       "along with Gucharmap; if not, write to the Free Software Foundation, Inc., "
+       "59 Temple Place, Suite 330, Boston, MA  02111-1307  USA"),
+    N_("Also you should have received a copy of the Unicode Copyright along "
+       "with Gucharmap; you can always find it at Unicode's website: "
+       "http://www.unicode.org/copyright.html")
+  };
+  license_trans = g_strconcat (_(license[0]), "\n\n", _(license[1]), "\n\n",
+			       _(license[2]), "\n\n", _(license[3]), "\n\n",
+			       _(license[4]), "\n\n", NULL);
 
   translator_credits = _("translator-credits");
   if (strcmp (translator_credits, "translator-credits") == 0)
@@ -341,14 +366,21 @@ help_about (GtkAction       *action,
 
   gtk_show_about_dialog (GTK_WINDOW (guw),
   			 "authors", authors,
-			 "comments", _("Character Map"),
-			 "copyright", "Copyright © 2004 Noah Levitt <nlevitt@columbia.edu>",
+			 "comments", _("GNOME Character Map\n"
+				       "based on Unicode Character Database"),
+			 "copyright", "Copyright © 2004 Noah Levitt <nlevitt@columbia.edu>\n"
+				      "Copyright © 1991-2005 Unicode, Inc.",
 			 "documenters", documenters,
+			 "license", license_trans,
 			 "logo", priv->icon,
+			 "name", _("Gucharmap"),
 			 "translator-credits", translator_credits,
 			 "version", VERSION,
-			 "name", _("gucharmap"),
+			 "website", "http://live.gnome.org/Gucharmap",
+			 "wrap-license", TRUE,
 			 NULL);
+
+  g_free (license_trans);
 }
 
 static void
@@ -489,7 +521,7 @@ static const GtkActionEntry menu_entries[] =
   { "PreviousChapter", NULL, N_("Previous Script"), "<control>Page_Up",
     NULL, G_CALLBACK (prev_chapter) },
 
-#if HAVE_GNOME
+#ifdef HAVE_GNOME
   { "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
     NULL, G_CALLBACK (help_contents) },
 #endif
@@ -533,7 +565,7 @@ static const char ui_info [] =
 "	 <menuitem name=\"GoPreviousChapterMenu\" action=\"PreviousChapter\" />"
 "    </menu>"
 "    <menu name=\"HelpMenu\" action=\"Help\">"
-#if HAVE_GNOME
+#ifdef HAVE_GNOME
 "	 <menuitem name=\"HelpContentsMenu\" action=\"HelpContents\" />"
 #endif
 "	 <menuitem name=\"HelpAboutMenu\" action=\"About\" />"
@@ -577,12 +609,7 @@ make_menu (GucharmapWindow *guw)
   			       gtk_ui_manager_get_accel_group (priv->uimanager) );
   
   priv->action_group = gtk_action_group_new ("gucharmap_actions");
-  gtk_action_group_set_translation_domain  (priv->action_group,
-					    GETTEXT_PACKAGE);
-  gtk_action_group_set_translate_func (priv->action_group,
-				       gucharmap_gettext,
-				       NULL,
-				       NULL);
+  gtk_action_group_set_translation_domain (priv->action_group, GETTEXT_PACKAGE);
 
   gtk_action_group_add_actions (priv->action_group,
   				menu_entries,
@@ -740,7 +767,7 @@ load_icon (GucharmapWindow *guw)
   gchar *package_root, *icon_path;
 
   package_root = g_win32_get_package_installation_directory (NULL, NULL);
-  icon_path = g_build_filename (package_root, "share", "pixmaps", "gucharmap.png");
+  icon_path = g_build_filename (package_root, "share", "icons", "hicolor", "48x48", "apps", "gucharmap.png");
   priv->icon = gdk_pixbuf_new_from_file (icon_path, &error);
   g_free (package_root);
   g_free (icon_path);
@@ -888,6 +915,8 @@ gucharmap_window_class_init (GucharmapWindowClass *clazz)
   GTK_WIDGET_CLASS (clazz)->show_all = show_all;
   G_OBJECT_CLASS (clazz)->finalize = window_finalize;
   g_type_class_add_private (clazz, sizeof (GucharmapWindowPrivate));
+
+  gucharmap_intl_ensure_initialized ();
 }
 
 GType 
